@@ -42,6 +42,21 @@ sub skip_if_lack_needed_socket_msghdr {
     return;
 }
 
+sub skip_if_missing_or_outdated_mojo {
+    my $count = shift;
+
+    skip 'No Mojo::IOLoop!', 1 if !eval { require Mojo::IOLoop };
+    skip 'No Mojo::Promise!', $count if !eval { require Mojo::Promise };
+    skip 'Loop can’t timer()!', $count if !Mojo::IOLoop->can('timer');
+
+    require Mojolicious;
+
+    my $min_ver = 8.15;
+    skip "Mojo is $Mojolicious::VERSION; needs >= $min_ver", $count if !eval { Mojolicious->VERSION($min_ver) };
+
+    return;
+}
+
 sub get_bin {
     return File::Which::which('dbus-run-session');
 }
